Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopyAll ¶
CopyAll copies a source file or a directory to destination and does it recursively. Directories along the destination path(s) are created as needed. Files are copied using io.Copy.
If overwrite is specified it silently overwrites existing destination files, otherwise returns an os.Exists.
Permissions of source files and directories carry over to destinations.
If any other error occurs is returned and it will be of type *os.PathError.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.